@@ -1,5 +1,5 @@
 # =====================================================================
-# Copyright (C) 1999-2005  Ingo Ruczinski and Charles Kooperberg
+# Copyright (C) 1999-2008  Ingo Ruczinski and Charles Kooperberg
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -394,8 +394,7 @@ plot.logreg <- function(x, pscript = FALSE, title = TRUE, ...)
          if(j == hm)
             par(mar = c(1.9, 0, 0, 0))
          dd <- data[ - c(1:2), j]
-         test <- hist(dd, probability = TRUE, breaks = brks,
-            plot = FALSE)
+         test <- hist(dd, breaks = brks, plot = FALSE)
          test <- c(test$density, test$counts)
          hist(dd, probability = TRUE, xlab = "", xaxt = "n",
             yaxt = "n", main = "", breaks = brks)
@@ -408,7 +407,6 @@ plot.logreg <- function(x, pscript = FALSE, title = TRUE, ...)
                abline(v=ww, lty=2)
          }
          pp <- paste("\ntrees:", data[1, j], "leaves:", data[2, j])
-         mm <- par$yaxp[2]
          text(brks[1], 0.95 * max(test), pp, adj = 0)
          if(j == 1)
             text(scb, 0.95 * max(test), " <== best model for unrandomized data", adj = 0)
